@@ -57,4 +57,20 @@ test_that("Coarse multiple meshes to large size", {
     c("493214", "493215")
   )
   
+  set.seed(123)
+  
+  res <- coarse_gather(rmesh(1, "10km"))
+  
+  skip_if(grepl("development", version$status))
+  expect_equal(
+    res,
+    "4929"
+  )
+  skip_if(!grepl("development", version$status))
+  expect_equal(
+    res,
+    "4728"
+  )
+  
+  
 })
